@@ -33,6 +33,11 @@
 #define HIG_IDENTATION		"    "
 #define NEVER_SENSITIVE		"never_sensitive"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 /* set sensitive and setup NEVER_SENSITIVE appropriately */
 static void
 hard_set_sensitive (GtkWidget *w, gboolean sensitivity)
@@ -84,7 +89,7 @@ properties_close_cb (GtkWidget *widget, gint arg, MultiloadApplet *ma)
 		case GTK_RESPONSE_HELP:
 
 			gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
-					"ghelp:multiload?multiload-prefs",
+					"help:mate-multiload/multiload-prefs",
 					gtk_get_current_event_time (),
 					&error);
 
@@ -199,6 +204,9 @@ add_page(GtkWidget *notebook, gchar *label)
 	GtkWidget *page_label;
 	
 	page = gtk_hbox_new(TRUE, 0);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	gtk_box_set_homogeneous (GTK_BOX (page), TRUE);
+#endif
 	page_label = gtk_label_new(label);
 	gtk_container_set_border_width(GTK_CONTAINER(page), 6);
 		
@@ -218,8 +226,6 @@ color_picker_set_cb(GtkColorButton *color_picker, gchar *key)
 
 	ma = g_object_get_data (G_OBJECT (color_picker), "MultiloadApplet");
 
-	prop_type = 0;
-	
 	if (strstr(key, "cpuload"))
 		prop_type = PROP_CPU;
 	else if (strstr(key, "memload"))
@@ -244,7 +250,9 @@ color_picker_set_cb(GtkColorButton *color_picker, gchar *key)
 	gdk_color_parse(color_string, 
 			&(ma->graphs[prop_type]->colors[g_ascii_digit_value(key[strlen(key) - 1]) ]) );
 	
+#if !GTK_CHECK_VERSION (3, 0, 0)
 	ma->graphs[prop_type]->colors_allocated = FALSE;
+#endif
 	
 	return;
 }
@@ -635,7 +643,6 @@ multiload_properties_cb (GtkAction       *action,
 			       gtk_widget_get_screen (GTK_WIDGET (ma->applet)));
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
 
