@@ -30,15 +30,18 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
-#include <gdk/gdkkeysyms-compat.h>
-#endif
 #include <gio/gio.h>
+#include <libmate-desktop/mate-aboutdialog.h>
 #include <mate-panel-applet.h>
 
 #include "trash-empty.h"
 #include "xstuff.h"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 typedef MatePanelAppletClass TrashAppletClass;
 
 typedef struct
@@ -187,11 +190,7 @@ trash_applet_size_allocate (GtkWidget    *widget,
 }
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 trash_applet_dispose (GObject *object)
-#else
-trash_applet_destroy (GtkObject *object)
-#endif
 {
   TrashApplet *applet = TRASH_APPLET (object);
 
@@ -211,11 +210,7 @@ trash_applet_destroy (GtkObject *object)
     g_object_unref (applet->icon);
   applet->icon = NULL;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   G_OBJECT_CLASS (trash_applet_parent_class)->dispose (object);
-#else
-  GTK_OBJECT_CLASS (trash_applet_parent_class)->destroy (object);
-#endif
 }
 
 static void
@@ -289,12 +284,12 @@ trash_applet_key_press (GtkWidget   *widget,
 
   switch (event->keyval)
     {
-     case GDK_KP_Enter:
-     case GDK_ISO_Enter:
-     case GDK_3270_Enter:
-     case GDK_Return:
-     case GDK_space:
-     case GDK_KP_Space:
+     case GDK_KEY_KP_Enter:
+     case GDK_KEY_ISO_Enter:
+     case GDK_KEY_3270_Enter:
+     case GDK_KEY_Return:
+     case GDK_KEY_space:
+     case GDK_KEY_KP_Space:
       trash_applet_open_folder (NULL, applet);
       return TRUE;
 
@@ -319,11 +314,7 @@ trash_applet_drag_motion (GtkWidget      *widget,
   GList *target;
 
   /* refuse drops of panel applets */
-#if GTK_CHECK_VERSION (3, 0, 0)
   for (target = gdk_drag_context_list_targets (context); target; target = target->next)
-#else
-  for (target = context->targets; target; target = target->next)
-#endif
     {
       const char *name = gdk_atom_name (target->data);
 
@@ -434,7 +425,7 @@ trash_applet_show_about (GtkAction   *action,
     NULL
   };
 
-  gtk_show_about_dialog (NULL,
+  mate_show_about_dialog (NULL,
                          "version", VERSION,
                          "copyright", "Copyright \xC2\xA9 2004 Michiel Sikkes,"
                                       "\xC2\xA9 2008 Ryan Lortie",
@@ -529,11 +520,7 @@ confirm_delete_immediately (GtkWidget *parent_view,
 
   response = gtk_dialog_run (GTK_DIALOG (dialog));
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   gtk_widget_destroy (GTK_WIDGET (dialog));
-#else
-  gtk_object_destroy (GTK_OBJECT (dialog));
-#endif
 
   return response == GTK_RESPONSE_YES;
 }
@@ -608,18 +595,10 @@ trash_applet_drag_data_received (GtkWidget        *widget,
 static void
 trash_applet_class_init (TrashAppletClass *class)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-#else
-  GtkObjectClass *gtkobject_class = GTK_OBJECT_CLASS (class);
-#endif
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   gobject_class->dispose = trash_applet_dispose;
-#else
-  gtkobject_class->destroy = trash_applet_destroy;
-#endif
   widget_class->size_allocate = trash_applet_size_allocate;
   widget_class->button_release_event = trash_applet_button_release;
   widget_class->key_press_event = trash_applet_key_press;
